aboutsummaryrefslogtreecommitdiff
path: root/obj_blob.go
diff options
context:
space:
mode:
Diffstat (limited to 'obj_blob.go')
-rw-r--r--obj_blob.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/obj_blob.go b/obj_blob.go
index 556a21fc..45d412ff 100644
--- a/obj_blob.go
+++ b/obj_blob.go
@@ -7,8 +7,8 @@ type Blob struct {
Data []byte
}
-// ObjType allows Blob to satisfy the Object interface.
-func (*Blob) ObjType() ObjType {
+// ObjectType allows Blob to satisfy the Object interface.
+func (*Blob) ObjectType() ObjectType {
return ObjBlob
}